@@ -22,8 +22,8 @@ class TransactionRepository:
     def fetch_transactions(self, user_id):
         return helpers.server_time_out_wrapper(self, self.do_fetch_transactions, user_id)
 
-    def fetch_distinct_user_ids(self, user_id):
-        return helpers.server_time_out_wrapper(self, self.do_fetch_distinct_user_ids(), user_id)
+    def fetch_distinct_user_ids(self):
+        return helpers.server_time_out_wrapper(self, self.do_fetch_distinct_user_ids())
 
     def insert_transaction(self, user_id, volume, symbol, value, price, currency, date, source, source_id, operation):
         return helpers.server_time_out_wrapper(self, self.do_insert_transaction, user_id, volume, symbol,
